@@ -1,6 +1,6 @@
-context("test-wSG")
+context("test-rcpp_wSG")
 
-test_that("smooth_wSG works", {
+test_that("rcpp_wSG works", {
     ## 1. Seq value
     x <- 1:100
     x[50] <- NA
@@ -8,11 +8,11 @@ test_that("smooth_wSG works", {
     halfwin <- 10
     w <- is.finite(x)
 
-    s1 <- smooth_wSG(x, halfwin, 1)
-    s2 <- smooth_wSG(x, halfwin, 1, w)
+    s1 <- rcpp_wSG(x, halfwin, 1)
+    s2 <- rcpp_wSG(x, halfwin, 1, w)
 
-    s2_1 <- smooth_wSG(x, halfwin, 2)
-    s2_2 <- smooth_wSG(x, halfwin, 2, w)
+    s2_1 <- rcpp_wSG(x, halfwin, 2)
+    s2_2 <- rcpp_wSG(x, halfwin, 2, w)
 
     expect_equal(s1, 1:100)
     expect_equal(s2, 1:100)
@@ -23,13 +23,13 @@ test_that("smooth_wSG works", {
     x2[50] <- NA
     x2[80] <- Inf
     w <- is.finite(x)
-    s3 <- smooth_wSG(x2, halfwin, 2)
-    s4 <- smooth_wSG(x2, halfwin, 2, w)
+    s3 <- rcpp_wSG(x2, halfwin, 2)
+    s4 <- rcpp_wSG(x2, halfwin, 2, w)
     expect_equal(s3, s4)
 })
 
-test_that("smooth_wSG works", {
+test_that("rcpp_wSG works", {
     x <- 1:100
-    s1 <- smooth_SG(x, halfwin = 3, d = 2)
+    s1 <- rcpp_SG(x, halfwin = 3, d = 2)
     expect_equal(x, s1)
 })
